@@ -1,6 +1,9 @@
 import atexit
+import contextlib
 import os
 import math
+import platform
+import signal
 import typing
 from typing import Union
 from rpy2.rinterface_lib import openrlib
@@ -32,6 +35,54 @@ R_NilValue = openrlib.rlib.R_NilValue
 
 endr = embedded.endr
 
+_evaluation_context = globalenv
+
+
+def get_evaluation_context() -> SexpEnvironment:
+    """Get the frame (environment) in which R code is currently evaluated."""
+    return _evaluation_context
+
+
+@contextlib.contextmanager
+def local_context(
+        env: typing.Optional[SexpEnvironment] = None,
+        use_rlock: bool = True
+) -> typing.Iterator[SexpEnvironment]:
+    """Local context for the evaluation of R code.
+
+    Args:
+    - env: an environment to use as a context. If not specified (None, the
+      default), a child environment to the current context is created.
+    - use_rlock: whether to use a threading lock (see the documentation about
+      "rlock". The default is True.
+
+    Returns:
+    Yield the environment (passed to env, or created).
+    """
+
+    global _evaluation_context
+
+    parent_frame = _evaluation_context
+    if env is None:
+        env = baseenv['new.env'](
+            baseenv['parent.frame']()
+            if parent_frame is None
+            else parent_frame)
+    try:
+        if use_rlock:
+            with openrlib.rlock:
+                _evaluation_context = env
+                yield env
+        else:
+            _evaluation_context = env
+            yield env
+    finally:
+        _evaluation_context = parent_frame
+
+
+def _sigint_handler(sig, frame):
+    raise KeyboardInterrupt()
+
 
 @_cdata_res_to_rinterface
 def parse(text: str, num: int = -1):
@@ -68,9 +119,10 @@ def evalr(source: str, maxlines: int = -1) -> sexp.Sexp:
 def vector_memoryview(obj: sexp.SexpVector,
                       sizeof_str: str, cast_str: str) -> memoryview:
     """
-    - sizeof_str: type in a string to use with ffi.sizeof()
+    :param:`obj` R vector
+    :param:`sizeof_str` Type in a string to use with ffi.sizeof()
         (for example "int")
-    - cast_str: type in a string to use with memoryview.cast()
+    :param:`cast_str` Type in a string to use with memoryview.cast()
         (for example "i")
     """
     b = openrlib.ffi.buffer(
@@ -120,7 +172,7 @@ class SexpSymbol(sexp.Sexp):
         return conversion._cchar_to_str(
             openrlib._STRING_VALUE(
                 self._sexpobject._cdata
-            )
+            ), 'utf-8'
         )
 
 
@@ -160,7 +212,7 @@ class SexpPromise(Sexp):
         :param:`env` The environment in which to evaluate the
           promise.
         """
-        if not env:
+        if env is None:
             env = globalenv
         return openrlib.rlib.Rf_eval(self.__sexp__._cdata, env)
 
@@ -530,11 +582,13 @@ class PairlistSexpVector(SexpVector):
                     ))
                 res_name = rmemory.protect(
                     rlib.Rf_allocVector(RTYPES.STRSXP, 1))
-                rlib.SET_STRING_ELT(
-                    res_name,
-                    0,
-                    rlib.PRINTNAME(rlib.TAG(item_cdata)))
-                rlib.Rf_namesgets(res_cdata, res_name)
+                item_cdata_name = rlib.PRINTNAME(rlib.TAG(item_cdata))
+                if _rinterface._TYPEOF(item_cdata_name) != rlib.NILSXP:
+                    rlib.SET_STRING_ELT(
+                        res_name,
+                        0,
+                        item_cdata_name)
+                    rlib.Rf_namesgets(res_cdata, res_name)
                 res = conversion._cdata_to_rinterface(res_cdata)
         elif isinstance(i, slice):
             iter_indices = range(*i.indices(len(self)))
@@ -612,30 +666,36 @@ class SexpClosure(Sexp):
             call_r = rmemory.protect(
                 _rinterface.build_rcall(self.__sexp__._cdata, args,
                                         kwargs.items()))
+            call_context = _evaluation_context
             res = rmemory.protect(
                 openrlib.rlib.R_tryEval(
                     call_r,
-                    globalenv.__sexp__._cdata,
-                    error_occured))
+                    call_context.__sexp__._cdata,
+                    error_occured)
+            )
             if error_occured[0]:
                 raise embedded.RRuntimeError(_rinterface._geterrmessage())
         return res
 
     @_cdata_res_to_rinterface
-    def rcall(self, keyvals, environment: SexpEnvironment):
+    def rcall(self, keyvals,
+              environment: typing.Optional[SexpEnvironment] = None):
         """Call/evaluate an R function.
 
         Args:
         - keyvals: a sequence of key/value (name/parameter) pairs. A
-            name/parameter that is None will indicated an unnamed parameter.
-            Like in R, keys/names do not have to be unique, partial matching
-            can be used, and named/unnamed parameters can occur at any position
-            in the sequence.
-        - environment: a R environment in which to evaluate the function.
+          name/parameter that is None will indicated an unnamed parameter.
+          Like in R, keys/names do not have to be unique, partial matching
+          can be used, and named/unnamed parameters can occur at any position
+          in the sequence.
+        - environment: an optional R environment to evaluate the function.
         """
         # TODO: check keyvals are pairs ?
+        if environment is None:
+            environment = _evaluation_context
         assert isinstance(environment, SexpEnvironment)
         error_occured = _rinterface.ffi.new('int *', 0)
+
         with memorymanagement.rmemory() as rmemory:
             call_r = rmemory.protect(
                 _rinterface.build_rcall(self.__sexp__._cdata, [],
@@ -802,13 +862,13 @@ def initr_simple() -> typing.Optional[int]:
 
 def initr_checkenv() -> typing.Optional[int]:
     # Force the internal initialization flag if there is an environment
-    # variable that indicates that R was alreay initialized in the current
+    # variable that indicates that R was already initialized in the current
     # process.
 
     status = None
     with openrlib.rlock:
         if embedded.is_r_externally_initialized():
-            embedded.setinitialized()
+            embedded._setinitialized()
         else:
             status = embedded._initr()
             embedded.set_python_process_info()
@@ -820,6 +880,25 @@ def initr_checkenv() -> typing.Optional[int]:
 initr = initr_checkenv
 
 
+def _update_R_ENC_PY():
+    conversion._R_ENC_PY[openrlib.rlib.CE_UTF8] = 'utf-8'
+
+    l10n_info = tuple(baseenv['l10n_info']())
+    if platform.system() == 'Windows':
+        val_latin1 = 'cp{:d}'.format(l10n_info[3][0])
+    else:
+        val_latin1 = 'latin1'
+    conversion._R_ENC_PY[openrlib.rlib.CE_LATIN1] = val_latin1
+
+    if l10n_info[1]:
+        val_native = conversion._R_ENC_PY[openrlib.rlib.CE_UTF8]
+    else:
+        val_native = val_latin1
+    conversion._R_ENC_PY[openrlib.rlib.CE_NATIVE] = val_native
+
+    conversion._R_ENC_PY[openrlib.rlib.CE_ANY] = 'utf-8'
+
+
 def _post_initr_setup() -> None:
 
     emptyenv.__sexp__ = _rinterface.SexpCapsule(openrlib.rlib.R_EmptyEnv)
@@ -858,10 +937,21 @@ def _post_initr_setup() -> None:
     )
     NA_Complex = na_values.NA_Complex
 
+    signal.signal(signal.SIGINT, _sigint_handler)
+    _update_R_ENC_PY()
+
 
 def rternalize(function: typing.Callable) -> SexpClosure:
-    """ Takes an arbitrary Python function and wrap it
-    in such a way that it can be called from the R side. """
+    """ Make a Python function callable from R.
+
+    Takes an arbitrary Python function and wrap it in such a way that
+    it can be called from the R side.
+
+    :param function: A Python callable object.
+    :return: A wrapped R object that can be use like any other rpy2
+    object.
+    """
+
     assert callable(function)
     rpy_fun = SexpExtPtr.from_pyobject(function)
     # TODO: this is a hack. Find a better way.
