@@ -41,11 +41,9 @@ typedef int R_len_t;
 
 #ifdef RPY2_RLEN_LONG
 typedef ptrdiff_t R_xlen_t;
-#endif
-
-#ifdef RPY2_RLEN_SHORT
+#else  /* RPY2_RLEN_LONG */
 typedef int R_xlen_t;
-#endif
+#endif  /* RPY2_RLEN_LONG */
 
 /* R_ext/Arith.h */
 extern double R_NaN;  /* IEEE NaN */
@@ -150,7 +148,7 @@ typedef enum { FALSE = 0, TRUE } Rboolean;
 
 /* include/Rembedded.h */
 int Rf_initialize_R(int ac, char **av);
-extern void Rf_initEmbeddedR(int argc, char *argv[]);
+extern int Rf_initEmbeddedR(int argc, char *argv[]);
 extern void R_RunExitFinalizers(void);
 extern void Rf_KillAllDevices(void);
 extern void R_CleanTempDir(void);
@@ -252,6 +250,7 @@ SEXP (CLOENV)(SEXP x);
 SEXP Rf_eval(SEXP, SEXP);
 SEXP R_tryEval(SEXP, SEXP, int*);
 
+Rboolean R_ToplevelExec(void (*fun)(void *), void *data);
 SEXP R_tryCatchError(SEXP (*fun)(void *data), void *data,
 		     SEXP (*hndlr)(SEXP cond, void *hdata), void *hdata);
 
@@ -343,6 +342,9 @@ extern SEXP R_ClassSymbol;
 extern SEXP R_NameSymbol;
 extern SEXP R_DimSymbol;
 
+/* include/Rinternals.h */
+Rboolean (Rf_isSymbol)(SEXP s);
+
 /* include/R_ext/Parse.h */
 typedef enum {
     PARSE_NULL,
@@ -356,6 +358,7 @@ SEXP R_ParseVector(SEXP text, int num, ParseStatus *status, SEXP srcfile);
 
 /* include/Rinterface.h */
 extern Rboolean R_Interactive ;
+extern void* R_GlobalContext;
 extern int R_SignalHandlers;
 extern uintptr_t R_CStackLimit;
 extern uintptr_t R_CStackStart;
@@ -373,14 +376,14 @@ typedef enum {
 
 #ifdef OSNAME_NT
 char *getDLLVersion(void);
-char *getRUser(void);
-char *get_R_HOME(void);
+extern char *getRUser(void);
+extern char *get_R_HOME(void);
 void setup_term_ui(void);
 extern int UserBreak;
 extern Rboolean AllDevicesKilled;
 void editorcleanall(void);
-int GA_initapp(int, char **);
-void GA_appcleanup(void);
+extern int GA_initapp(int, char **);
+extern void GA_appcleanup(void);
 void readconsolecfg(void);
 
 typedef int (*blah1) (const char *, char *, int, int);
@@ -393,7 +396,8 @@ typedef int (*blah5) (const char *);
 typedef void (*blah6) (int);
 typedef void (*blah7) (const char *, int, int);
 typedef enum {RGui, RTerm, LinkDLL} UImode;
-#endif
+#else  /* OSNAME_NT */
+#endif  /* OSNAME_NT */
 
 /* preprocess-define-begin */
 #define R_SIZE_T size_t
@@ -428,20 +432,19 @@ typedef struct
   blah6 Busy;
   UImode CharacterMode;
   blah7 WriteConsoleEx; /* used only if WriteConsole is NULL */
-#endif
+#else  /* OSNAME_NT */
+#endif  /* OSNAME_NT */
 } structRstart;
 
 typedef structRstart *Rstart;
 
-void R_DefParams(Rstart);
-void R_SetParams(Rstart);
+void R_DefParams(Rstart rs);
+void R_SetParams(Rstart rs);
 
-#ifdef OSNAME_NT
-void R_SetWin32(Rstart);
-#endif
-
-void R_SizeFromEnv(Rstart);
-void R_common_command_line(int *, char **, Rstart);
+/*
+void R_SizeFromEnv(Rstart rs);
+void R_common_command_line(int *n, char **argv, Rstart rs);
+*/
 
 void R_set_command_line_arguments(int argc, char **argv);
 
@@ -452,6 +455,7 @@ void Rf_mainloop(void);
 extern FILE *R_Consolefile;
 extern FILE *R_Outputfile;
 
+#ifdef R_INTERFACE_PTRS
 extern void (*ptr_R_Suicide)(const char *);
 extern void (*ptr_R_ShowMessage)(const char *);
 extern int  (*ptr_R_ReadConsole)(const char *, unsigned char *, int, int);
@@ -478,6 +482,7 @@ extern SEXP (*ptr_do_selectlist)(SEXP, SEXP, SEXP, SEXP);
 extern SEXP (*ptr_do_dataentry)(SEXP, SEXP, SEXP, SEXP);
 extern SEXP (*ptr_do_dataviewer)(SEXP, SEXP, SEXP, SEXP);
 extern void (*ptr_R_ProcessEvents)(void);
+#endif  /* R_INTERFACE_PTRS */
 
 typedef unsigned int R_NativePrimitiveArgType;
 
